{% extends "admin/change_form.html" %}{% load i18n static admin_modify %}{% load admin_urls %}

{% block content %}
    <style type="text/css">
        #info *{
            font-size: 14pt;
            line-height: 14pt;
            background-color: #dcdcdc;
        }

        /* resetting css for the traceback */
        #original_traceback h1 {
            color: #000000;
            font-size: 2em;
            font-weight: bold;
        }

        #original_traceback h2 {
            font-size: 1.5em;
            font-weight: bold;
        }

        #original_traceback th {
            font-size: 13px;
            height: 15px;
            font-weight: bold;
            border: none;
        }

        #original_traceback td {
            border: none;
        }

        #original_traceback tt,
        #original_traceback code,
        #original_traceback kbd,
        #original_traceback samp {
            font-family: monospace;
        }

        #original_traceback ul.traceback {
            list-style-type: none;
            color: #222;
        }
        #original_traceback .traceback li {
            list-style-type: none;
        }
        #original_traceback .context li {
            line-height: normal;
            list-style-position: inside;
            list-style-type: decimal;
        }
    </style>
    <table id="info">
        <tr>
            <td>{{ original.datetime }}</td>
            <td>{{ original.username }}</td>
        </tr>
    </table>

    <br/>

    <div id="original_traceback">
        {{ original.traceback|safe }}
    </div>
{% endblock content %}
